@@ -11,7 +11,7 @@
 # URL        : https://github.com/john-james-ai/studioai                                           #
 # ------------------------------------------------------------------------------------------------ #
 # Created    : Saturday August 26th 2023 06:25:27 am                                               #
-# Modified   : Monday August 28th 2023 07:41:05 am                                                 #
+# Modified   : Sunday September 3rd 2023 10:09:21 pm                                               #
 # ------------------------------------------------------------------------------------------------ #
 # License    : MIT License                                                                         #
 # Copyright  : (c) 2023 John James                                                                 #
@@ -117,7 +117,7 @@ class SeabornCanvas(Canvas):
 class Visualizer(VisualizerABC):  # pragma: no cover
     """Wrapper for Seaborn plotizations."""
 
-    def __init__(self, canvas: SeabornCanvas = None):
+    def __init__(self, canvas: SeabornCanvas):
         super().__init__(canvas)
 
     def lineplot(
@@ -152,7 +152,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
 
         """
         palette = self._canvas.palette if hue is not None else None
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         if ax is None:
             fig, ax = self._canvas.get_figaxes()
@@ -202,7 +202,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
 
         """
         palette = self._canvas.palette if hue is not None else None
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         if ax is None:
             fig, ax = self._canvas.get_figaxes()
@@ -258,7 +258,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
 
         """
         palette = self._canvas.palette if hue is not None else None
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         if ax is None:
             fig, ax = self._canvas.get_figaxes()
@@ -310,7 +310,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
 
         """
         palette = self._canvas.palette if hue is not None else None
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         if ax is None:
             fig, ax = self._canvas.get_figaxes()
@@ -328,6 +328,51 @@ class Visualizer(VisualizerABC):  # pragma: no cover
         if title is not None:
             ax.set_title(title)
 
+    def countplot(
+        self,
+        data: Union[pd.DataFrame, np.ndarray] = None,
+        x: str = None,
+        y: str = None,
+        hue: str = None,
+        title: str = None,
+        ax: plt.Axes = None,
+        *args,
+        **kwargs,
+    ) -> None:
+        """Show the counts of observations in each categorical bin using bars.
+
+        A count plot can be thought of as a histogram across a categorical, instead of quantitative, variable. The basic API and options are identical to those for barplot(), so you can compare counts across nested variables.
+
+        Args:
+            data (Union[pd.DataFrame, np.ndarray]): Input data structure. Either a long-form
+                collection of vectors that can be assigned to named variables or a wide-form dataset
+                that will be internally reshaped
+            x,y (str): Keys in data.
+            hue (str): Grouping variable that will produce lines with different colors. Can be either categorical or numeric, although color mapping will behave differently in latter case.
+            title (str): Title for the plot. Optional
+            ax: (plt.Axes): A matplotlib Axes object. Optional. If not provide, one will be obtained from the canvas.
+
+
+        """
+        palette = self._canvas.palette if hue is not None else "Blues_r"
+        data = data.any() or self._data.any()
+
+        if ax is None:
+            fig, ax = self._canvas.get_figaxes()
+
+        sns.countplot(
+            data=data,
+            x=x,
+            y=y,
+            hue=hue,
+            ax=ax,
+            palette=palette,
+            *args,
+            **kwargs,
+        )
+        if title is not None:
+            ax.set_title(title)
+
     def kdeplot(
         self,
         data: Union[pd.DataFrame, np.ndarray] = None,
@@ -357,7 +402,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
 
         """
         palette = self._canvas.palette if hue is not None else None
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         if ax is None:
             fig, ax = self._canvas.get_figaxes()
@@ -407,7 +452,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
 
         """
         palette = self._canvas.palette if hue is not None else None
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         if ax is None:
             fig, ax = self._canvas.get_figaxes()
@@ -454,7 +499,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
 
         """
         palette = self._canvas.palette if hue is not None else None
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         if ax is None:
             fig, ax = self._canvas.get_figaxes()
@@ -506,7 +551,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
 
         """
         palette = self._canvas.palette if hue is not None else None
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         if ax is None:
             fig, ax = self._canvas.get_figaxes()
@@ -546,7 +591,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
 
 
         """
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         if ax is None:
             fig, ax = self._canvas.get_figaxes()
@@ -590,7 +635,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
 
 
         """
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         if ax is None:
             fig, ax1 = self._canvas.get_figaxes()
@@ -655,7 +700,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
 
         """
         palette = self._canvas.palette if hue is not None else None
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         g = sns.pairplot(
             data=data,
@@ -693,7 +738,7 @@ class Visualizer(VisualizerABC):  # pragma: no cover
         """
 
         palette = self._canvas.palette if hue is not None else None
-        data = data or self._data
+        data = data.any() or self._data.any()
 
         g = sns.jointplot(
             data=data,
